{% extends "admin/change_form.html" %}
{% load i18n %}

{% block object-tools-items %}
{{ block.super }}
<li><a href="{% url "blog-preview-item" original.slug  %}" class="viewsitelink">{% trans "Preview" %}</a></li>
{% endblock %}